@@ -138,7 +138,6 @@ UNBUILDABLE_IMAGES = {
         "nova-spicehtml5proxy",  # Missing spicehtml5 package
         "opendaylight",          # Missing opendaylight repo
         "ovsdpdk",               # Not supported on CentOS
-        "sensu-base",            # Dropped by CentOS
         "tgtd",                  # Not supported on CentOS 8
     },
 
@@ -150,7 +149,6 @@ UNBUILDABLE_IMAGES = {
         "opendaylight",  # no binary package
         "ovsdpdk",
         "qdrouterd",
-        "sensu-base",
     },
 
     'ubuntu': {
@@ -159,11 +157,6 @@ UNBUILDABLE_IMAGES = {
 
     'ubuntu+aarch64': {
         "kibana",        # no binary package
-        "sensu-base",    # no binary package
-    },
-
-    'ubuntu+ppc64le': {
-        "sensu-base",    # no binary package
     },
 
     'centos+aarch64': {
@@ -804,6 +797,7 @@ class KollaWorker(object):
             PROJECT_ROOT,
             os.path.join(sys.prefix, 'share/kolla'),
             os.path.join(sys.prefix, 'local/share/kolla'),
+            os.path.join(os.getenv('HOME', ''), '.local/share/kolla'),
             # NOTE(zioproto): When Kolla is used within a snap, the env var
             #                 $SNAP is the directory where the snap is mounted.
             #                 https://github.com/zioproto/snap-kolla
